@@ -8,7 +8,7 @@ use Class::Utils qw(set_params split_params);
 use Error::Pure qw(err);
 use Scalar::Util qw(blessed);
 
-our $VERSION = 0.08;
+our $VERSION = 0.09;
 
 # Constructor.
 sub new {
@@ -110,7 +110,7 @@ sub _process_css {
 		err 'Message types must be a hash reference.';
 	}
 
-	foreach my $message_type (keys %{$message_types_hr}) {
+	foreach my $message_type (sort keys %{$message_types_hr}) {
 		$self->{'css'}->put(
 			['s', '.'.$message_type],
 			['d', 'color', $message_types_hr->{$message_type}],
@@ -351,6 +351,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.08
+0.09
 
 =cut
